pub struct ResolveModule { /* private fields */ }Expand description
A type representing a Module, converted from a type that implements Module.
Implementations
Sourceimpl ResolveModule
impl ResolveModule
Sourcepub fn new<T: Module + 'static>() -> Self
pub fn new<T: Module + 'static>() -> Self
Create a ResolveModule from a type that implements Module.
Sourcepub fn eager_create(&self) -> bool
pub fn eager_create(&self) -> bool
Whether the providers included in the module should be created eagerly.